[PATCH] drm/amdgpu: one pde of 4 levels at least 512GB

Chunming Zhou David1.Zhou at amd.com
Tue Mar 28 03:46:41 UTC 2017


Change-Id: I9d764e6e6cf214e64bd79435a8bbb4063260dc11
Signed-off-by: Chunming Zhou <David1.Zhou at amd.com>
---
 drivers/gpu/drm/amd/amdgpu/gmc_v9_0.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/gmc_v9_0.c b/drivers/gpu/drm/amd/amdgpu/gmc_v9_0.c
index c29a477..b7ec537 100644
--- a/drivers/gpu/drm/amd/amdgpu/gmc_v9_0.c
+++ b/drivers/gpu/drm/amd/amdgpu/gmc_v9_0.c
@@ -500,11 +500,11 @@ static int gmc_v9_0_vm_init(struct amdgpu_device *adev)
 	 * amdkfd will use VMIDs 8-15
 	 */
 	adev->vm_manager.num_ids = AMDGPU_NUM_OF_VMIDS;
 	/* Because of four level VMPTs, vm size at least is 256GB.
 	256TB is OK as well */
-	if (amdgpu_vm_size < 256) {
-		DRM_WARN("vm size at least is 256GB!\n");
-		amdgpu_vm_size = 256;
+	if (amdgpu_vm_size < 512) {
+		DRM_WARN("vm size at least is 512GB!\n");
+		amdgpu_vm_size = 512;
 	}
 	adev->vm_manager.num_level = 3;
 	amdgpu_vm_manager_init(adev);
@@ -500,11 +500,11 @@ static int gmc_v9_0_vm_init(struct amdgpu_device *adev)
 	 */
 	adev->vm_manager.num_ids = AMDGPU_NUM_OF_VMIDS;
-	/* Because of four level VMPTs, vm size at least is 256GB.
+	/* Because of four level VMPTs, vm size at least is 512GB.
 	256TB is OK as well */
-- 
1.9.1



More information about the amd-gfx mailing list